@@ -5,7 +5,8 @@ from pyhon.commands import HonCommand
 
 class HonDevice:
     def __init__(self, connector, appliance):
-        appliance["attributes"] = {v["parName"]: v["parValue"] for v in appliance["attributes"]}
+        if attributes := appliance.get("attributes"):
+            appliance["attributes"] = {v["parName"]: v["parValue"] for v in attributes}
         self._appliance = appliance
         self._connector = connector
         self._appliance_model = {}
@@ -81,6 +82,20 @@ class HonDevice:
     def appliance(self):
         return self._appliance
 
+    async def _recover_last_command_states(self, commands):
+        command_history = await self._connector.command_history(self)
+        for name, command in commands.items():
+            last = next((index for (index, d) in enumerate(command_history) if d.get("command", {}).get("commandName") == name), None)
+            if last is None:
+                continue
+            parameters = command_history[last].get("command", {}).get("parameters", {})
+            if command._multi and parameters.get("program"):
+                command.set_program(parameters.pop("program").split(".")[-1].lower())
+                command = self.commands[name]
+            for key, data in command.settings.items():
+                if parameters.get(key) is not None:
+                    data.value = parameters.get(key)
+
     async def load_commands(self):
         raw = await self._connector.load_commands(self)
         self._appliance_model = raw.pop("applianceModel")
@@ -92,11 +107,13 @@ class HonDevice:
                 commands[command] = HonCommand(command, attr, self._connector, self)
             elif "parameters" in attr[list(attr)[0]]:
                 multi = {}
-                for category, attr2 in attr.items():
-                    cmd = HonCommand(command, attr2, self._connector, self, multi=multi, category=category)
-                    multi[category] = cmd
+                for program, attr2 in attr.items():
+                    program = program.split(".")[-1].lower()
+                    cmd = HonCommand(command, attr2, self._connector, self, multi=multi, program=program)
+                    multi[program] = cmd
                     commands[command] = cmd
         self._commands = commands
+        await self._recover_last_command_states(commands)
 
     @property
     def settings(self):
